@@ -6,6 +6,7 @@
 #include <float.h>
 #include <direct.h>
 #include <ctype.h>
+#include <stdlib.h>
 
 /* realloc does not support NULL as argument */
 
@@ -25,13 +26,14 @@
 #define HAVE_VSNPRINTF 1
 #define HAVE_SYS_TYPES_H 1
 #define HAVE_SYS_STAT_H 1
+#define HAVE_RRD_GRAPH 1
 
 /* Define to 1 if you have the ANSI C header files. */
 #define STDC_HEADERS 1
 
-#define NUMVERS 1.4030
+#define NUMVERS 1.4050
 #define PACKAGE_NAME "rrdtool"
-#define PACKAGE_VERSION "1.4.3"
+#define PACKAGE_VERSION "1.4.5"
 #define PACKAGE_STRING PACKAGE_NAME " " PACKAGE_VERSION
 
 #define isinf(a) (_fpclass(a) == _FPCLASS_NINF || _fpclass(a) == _FPCLASS_PINF)
